@@ -232,18 +232,6 @@ extern des_LTX__mcrypt_get_supported_key_sizes();
 extern des_LTX__mcrypt_get_algorithms_name();
 extern des_LTX__mcrypt_self_test();
 extern des_LTX__mcrypt_algorithm_version();
-extern panama_LTX__mcrypt_set_key();
-extern panama_LTX__mcrypt_encrypt();
-extern panama_LTX__mcrypt_decrypt();
-extern panama_LTX__mcrypt_get_size();
-extern panama_LTX__mcrypt_get_block_size();
-extern panama_LTX__is_block_algorithm();
-extern panama_LTX__mcrypt_get_key_size();
-extern panama_LTX__mcrypt_get_algo_iv_size();
-extern panama_LTX__mcrypt_get_supported_key_sizes();
-extern panama_LTX__mcrypt_get_algorithms_name();
-extern panama_LTX__mcrypt_self_test();
-extern panama_LTX__mcrypt_algorithm_version();
 extern rijndael_256_LTX__mcrypt_set_key();
 extern rijndael_256_LTX__mcrypt_encrypt();
 extern rijndael_256_LTX__mcrypt_decrypt();
@@ -428,8 +416,6 @@ const mcrypt_preloaded mps[] = {
 	{"stream_LTX__mcrypt_get_modes_name", stream_LTX__mcrypt_get_modes_name},
 	{"stream_LTX__mcrypt_mode_get_size", stream_LTX__mcrypt_mode_get_size},
 	{"stream_LTX__mcrypt_mode_version", stream_LTX__mcrypt_mode_version},
-	{"threeway", NULL}, 
-	{"cast-128", NULL}, 
 	{"cast-128", NULL}, 
 	{"cast_128_LTX__mcrypt_set_key", cast_128_LTX__mcrypt_set_key},
 	{"cast_128_LTX__mcrypt_encrypt", cast_128_LTX__mcrypt_encrypt},
@@ -443,7 +429,6 @@ const mcrypt_preloaded mps[] = {
 	{"cast_128_LTX__mcrypt_self_test", cast_128_LTX__mcrypt_self_test},
 	{"cast_128_LTX__mcrypt_algorithm_version", cast_128_LTX__mcrypt_algorithm_version},
 	{"gost", NULL}, 
-	{"gost", NULL}, 
 	{"gost_LTX__mcrypt_set_key", gost_LTX__mcrypt_set_key},
 	{"gost_LTX__mcrypt_encrypt", gost_LTX__mcrypt_encrypt},
 	{"gost_LTX__mcrypt_decrypt", gost_LTX__mcrypt_decrypt},
@@ -456,7 +441,6 @@ const mcrypt_preloaded mps[] = {
 	{"gost_LTX__mcrypt_self_test", gost_LTX__mcrypt_self_test},
 	{"gost_LTX__mcrypt_algorithm_version", gost_LTX__mcrypt_algorithm_version},
 	{"rijndael-128", NULL}, 
-	{"rijndael-128", NULL}, 
 	{"rijndael_128_LTX__mcrypt_set_key", rijndael_128_LTX__mcrypt_set_key},
 	{"rijndael_128_LTX__mcrypt_encrypt", rijndael_128_LTX__mcrypt_encrypt},
 	{"rijndael_128_LTX__mcrypt_decrypt", rijndael_128_LTX__mcrypt_decrypt},
@@ -468,8 +452,6 @@ const mcrypt_preloaded mps[] = {
 	{"rijndael_128_LTX__mcrypt_get_algorithms_name", rijndael_128_LTX__mcrypt_get_algorithms_name},
 	{"rijndael_128_LTX__mcrypt_self_test", rijndael_128_LTX__mcrypt_self_test},
 	{"rijndael_128_LTX__mcrypt_algorithm_version", rijndael_128_LTX__mcrypt_algorithm_version},
-	{"safer-sk64", NULL}, 
-	{"twofish", NULL}, 
 	{"twofish", NULL}, 
 	{"twofish_LTX__mcrypt_set_key", twofish_LTX__mcrypt_set_key},
 	{"twofish_LTX__mcrypt_encrypt", twofish_LTX__mcrypt_encrypt},
@@ -483,7 +465,6 @@ const mcrypt_preloaded mps[] = {
 	{"twofish_LTX__mcrypt_self_test", twofish_LTX__mcrypt_self_test},
 	{"twofish_LTX__mcrypt_algorithm_version", twofish_LTX__mcrypt_algorithm_version},
 	{"arcfour", NULL}, 
-	{"arcfour", NULL}, 
 	{"arcfour_LTX__mcrypt_set_key", arcfour_LTX__mcrypt_set_key},
 	{"arcfour_LTX__mcrypt_encrypt", arcfour_LTX__mcrypt_encrypt},
 	{"arcfour_LTX__mcrypt_decrypt", arcfour_LTX__mcrypt_decrypt},
@@ -497,7 +478,6 @@ const mcrypt_preloaded mps[] = {
 	{"arcfour_LTX__mcrypt_self_test", arcfour_LTX__mcrypt_self_test},
 	{"arcfour_LTX__mcrypt_algorithm_version", arcfour_LTX__mcrypt_algorithm_version},
 	{"cast-256", NULL}, 
-	{"cast-256", NULL}, 
 	{"cast_256_LTX__mcrypt_set_key", cast_256_LTX__mcrypt_set_key},
 	{"cast_256_LTX__mcrypt_encrypt", cast_256_LTX__mcrypt_encrypt},
 	{"cast_256_LTX__mcrypt_decrypt", cast_256_LTX__mcrypt_decrypt},
@@ -510,7 +490,6 @@ const mcrypt_preloaded mps[] = {
 	{"cast_256_LTX__mcrypt_self_test", cast_256_LTX__mcrypt_self_test},
 	{"cast_256_LTX__mcrypt_algorithm_version", cast_256_LTX__mcrypt_algorithm_version},
 	{"loki97", NULL}, 
-	{"loki97", NULL}, 
 	{"loki97_LTX__mcrypt_set_key", loki97_LTX__mcrypt_set_key},
 	{"loki97_LTX__mcrypt_encrypt", loki97_LTX__mcrypt_encrypt},
 	{"loki97_LTX__mcrypt_decrypt", loki97_LTX__mcrypt_decrypt},
@@ -523,7 +502,6 @@ const mcrypt_preloaded mps[] = {
 	{"loki97_LTX__mcrypt_self_test", loki97_LTX__mcrypt_self_test},
 	{"loki97_LTX__mcrypt_algorithm_version", loki97_LTX__mcrypt_algorithm_version},
 	{"rijndael-192", NULL}, 
-	{"rijndael-192", NULL}, 
 	{"rijndael_192_LTX__mcrypt_set_key", rijndael_192_LTX__mcrypt_set_key},
 	{"rijndael_192_LTX__mcrypt_encrypt", rijndael_192_LTX__mcrypt_encrypt},
 	{"rijndael_192_LTX__mcrypt_decrypt", rijndael_192_LTX__mcrypt_decrypt},
@@ -536,7 +514,6 @@ const mcrypt_preloaded mps[] = {
 	{"rijndael_192_LTX__mcrypt_self_test", rijndael_192_LTX__mcrypt_self_test},
 	{"rijndael_192_LTX__mcrypt_algorithm_version", rijndael_192_LTX__mcrypt_algorithm_version},
 	{"saferplus", NULL}, 
-	{"saferplus", NULL}, 
 	{"saferplus_LTX__mcrypt_set_key", saferplus_LTX__mcrypt_set_key},
 	{"saferplus_LTX__mcrypt_encrypt", saferplus_LTX__mcrypt_encrypt},
 	{"saferplus_LTX__mcrypt_decrypt", saferplus_LTX__mcrypt_decrypt},
@@ -549,7 +526,6 @@ const mcrypt_preloaded mps[] = {
 	{"saferplus_LTX__mcrypt_self_test", saferplus_LTX__mcrypt_self_test},
 	{"saferplus_LTX__mcrypt_algorithm_version", saferplus_LTX__mcrypt_algorithm_version},
 	{"wake", NULL}, 
-	{"wake", NULL}, 
 	{"wake_LTX__mcrypt_set_key", wake_LTX__mcrypt_set_key},
 	{"wake_LTX__mcrypt_encrypt", wake_LTX__mcrypt_encrypt},
 	{"wake_LTX__mcrypt_decrypt", wake_LTX__mcrypt_decrypt},
@@ -563,7 +539,6 @@ const mcrypt_preloaded mps[] = {
 	{"wake_LTX__mcrypt_self_test", wake_LTX__mcrypt_self_test},
 	{"wake_LTX__mcrypt_algorithm_version", wake_LTX__mcrypt_algorithm_version},
 	{"blowfish-compat", NULL}, 
-	{"blowfish-compat", NULL}, 
 	{"blowfish_compat_LTX__mcrypt_set_key", blowfish_compat_LTX__mcrypt_set_key},
 	{"blowfish_compat_LTX__mcrypt_encrypt", blowfish_compat_LTX__mcrypt_encrypt},
 	{"blowfish_compat_LTX__mcrypt_decrypt", blowfish_compat_LTX__mcrypt_decrypt},
@@ -576,7 +551,6 @@ const mcrypt_preloaded mps[] = {
 	{"blowfish_compat_LTX__mcrypt_self_test", blowfish_compat_LTX__mcrypt_self_test},
 	{"blowfish_compat_LTX__mcrypt_algorithm_version", blowfish_compat_LTX__mcrypt_algorithm_version},
 	{"des", NULL}, 
-	{"des", NULL}, 
 	{"des_LTX__mcrypt_set_key", des_LTX__mcrypt_set_key},
 	{"des_LTX__mcrypt_encrypt", des_LTX__mcrypt_encrypt},
 	{"des_LTX__mcrypt_decrypt", des_LTX__mcrypt_decrypt},
@@ -588,21 +562,6 @@ const mcrypt_preloaded mps[] = {
 	{"des_LTX__mcrypt_get_algorithms_name", des_LTX__mcrypt_get_algorithms_name},
 	{"des_LTX__mcrypt_self_test", des_LTX__mcrypt_self_test},
 	{"des_LTX__mcrypt_algorithm_version", des_LTX__mcrypt_algorithm_version},
-	{"panama", NULL}, 
-	{"panama", NULL}, 
-	{"panama_LTX__mcrypt_set_key", panama_LTX__mcrypt_set_key},
-	{"panama_LTX__mcrypt_encrypt", panama_LTX__mcrypt_encrypt},
-	{"panama_LTX__mcrypt_decrypt", panama_LTX__mcrypt_decrypt},
-	{"panama_LTX__mcrypt_get_size", panama_LTX__mcrypt_get_size},
-	{"panama_LTX__mcrypt_get_block_size", panama_LTX__mcrypt_get_block_size},
-	{"panama_LTX__is_block_algorithm", panama_LTX__is_block_algorithm},
-	{"panama_LTX__mcrypt_get_key_size", panama_LTX__mcrypt_get_key_size},
-	{"panama_LTX__mcrypt_get_algo_iv_size", panama_LTX__mcrypt_get_algo_iv_size},
-	{"panama_LTX__mcrypt_get_supported_key_sizes", panama_LTX__mcrypt_get_supported_key_sizes},
-	{"panama_LTX__mcrypt_get_algorithms_name", panama_LTX__mcrypt_get_algorithms_name},
-	{"panama_LTX__mcrypt_self_test", panama_LTX__mcrypt_self_test},
-	{"panama_LTX__mcrypt_algorithm_version", panama_LTX__mcrypt_algorithm_version},
-	{"rijndael-256", NULL}, 
 	{"rijndael-256", NULL}, 
 	{"rijndael_256_LTX__mcrypt_set_key", rijndael_256_LTX__mcrypt_set_key},
 	{"rijndael_256_LTX__mcrypt_encrypt", rijndael_256_LTX__mcrypt_encrypt},
@@ -616,7 +575,6 @@ const mcrypt_preloaded mps[] = {
 	{"rijndael_256_LTX__mcrypt_self_test", rijndael_256_LTX__mcrypt_self_test},
 	{"rijndael_256_LTX__mcrypt_algorithm_version", rijndael_256_LTX__mcrypt_algorithm_version},
 	{"serpent", NULL}, 
-	{"serpent", NULL}, 
 	{"serpent_LTX__mcrypt_set_key", serpent_LTX__mcrypt_set_key},
 	{"serpent_LTX__mcrypt_encrypt", serpent_LTX__mcrypt_encrypt},
 	{"serpent_LTX__mcrypt_decrypt", serpent_LTX__mcrypt_decrypt},
@@ -629,7 +587,6 @@ const mcrypt_preloaded mps[] = {
 	{"serpent_LTX__mcrypt_self_test", serpent_LTX__mcrypt_self_test},
 	{"serpent_LTX__mcrypt_algorithm_version", serpent_LTX__mcrypt_algorithm_version},
 	{"xtea", NULL}, 
-	{"xtea", NULL}, 
 	{"xtea_LTX__mcrypt_set_key", xtea_LTX__mcrypt_set_key},
 	{"xtea_LTX__mcrypt_encrypt", xtea_LTX__mcrypt_encrypt},
 	{"xtea_LTX__mcrypt_decrypt", xtea_LTX__mcrypt_decrypt},
@@ -642,7 +599,6 @@ const mcrypt_preloaded mps[] = {
 	{"xtea_LTX__mcrypt_self_test", xtea_LTX__mcrypt_self_test},
 	{"xtea_LTX__mcrypt_algorithm_version", xtea_LTX__mcrypt_algorithm_version},
 	{"blowfish", NULL}, 
-	{"blowfish", NULL}, 
 	{"blowfish_LTX__mcrypt_set_key", blowfish_LTX__mcrypt_set_key},
 	{"blowfish_LTX__mcrypt_encrypt", blowfish_LTX__mcrypt_encrypt},
 	{"blowfish_LTX__mcrypt_decrypt", blowfish_LTX__mcrypt_decrypt},
@@ -655,7 +611,6 @@ const mcrypt_preloaded mps[] = {
 	{"blowfish_LTX__mcrypt_self_test", blowfish_LTX__mcrypt_self_test},
 	{"blowfish_LTX__mcrypt_algorithm_version", blowfish_LTX__mcrypt_algorithm_version},
 	{"enigma", NULL}, 
-	{"enigma", NULL}, 
 	{"enigma_LTX__mcrypt_set_key", enigma_LTX__mcrypt_set_key},
 	{"enigma_LTX__mcrypt_encrypt", enigma_LTX__mcrypt_encrypt},
 	{"enigma_LTX__mcrypt_decrypt", enigma_LTX__mcrypt_decrypt},
@@ -669,7 +624,6 @@ const mcrypt_preloaded mps[] = {
 	{"enigma_LTX__mcrypt_self_test", enigma_LTX__mcrypt_self_test},
 	{"enigma_LTX__mcrypt_algorithm_version", enigma_LTX__mcrypt_algorithm_version},
 	{"rc2", NULL}, 
-	{"rc2", NULL}, 
 	{"rc2_LTX__mcrypt_set_key", rc2_LTX__mcrypt_set_key},
 	{"rc2_LTX__mcrypt_encrypt", rc2_LTX__mcrypt_encrypt},
 	{"rc2_LTX__mcrypt_decrypt", rc2_LTX__mcrypt_decrypt},
@@ -681,8 +635,6 @@ const mcrypt_preloaded mps[] = {
 	{"rc2_LTX__mcrypt_get_algorithms_name", rc2_LTX__mcrypt_get_algorithms_name},
 	{"rc2_LTX__mcrypt_self_test", rc2_LTX__mcrypt_self_test},
 	{"rc2_LTX__mcrypt_algorithm_version", rc2_LTX__mcrypt_algorithm_version},
-	{"safer-sk128", NULL}, 
-	{"tripledes", NULL}, 
 	{"tripledes", NULL}, 
 	{"tripledes_LTX__mcrypt_set_key", tripledes_LTX__mcrypt_set_key},
 	{"tripledes_LTX__mcrypt_encrypt", tripledes_LTX__mcrypt_encrypt},
